import argparse
import logging
import os
import yaml
from monobot.bot import MonoBot


EXAMPLE_CONFIG = """
---
# Add either oauth or credentials
oauth:
    id: <client id>
    secret: <client secret>
    uri: <redirect uri>
    token: <refresh token>
credentials:
    username: <bot username>
    password: <bot password>
bot:
    verbose: true
    thread: <link to thread to post to>
    delay: <number of seconds between comment submissions>
...
"""


def main():
    parser = argparse.ArgumentParser(description="Builds CSV from staging database.")
    parser.add_argument("-c", "--config", help="Config file (if not settings.yaml)", default=None)
    args = parser.parse_args()
    logging.basicConfig()
    if not args.config and not os.path.isfile(os.path.join(os.getcwd(), "settings.yaml")):
        print("Not config provided and not settings.yaml found in this path.\nTo use monobot, please create a file "
              "based on the following example YAML config:")
        print(EXAMPLE_CONFIG)
        return
    try:
        config = yaml.load(open(args.config or "settings.yaml"))
    except:
        # Catch both bath paths and YAML issues
        print("Could not load configuration file: {}".format(args.config))
        return
    bot = MonoBot(config)
    bot.shitpost()


if __name__ == "__main__":
    main()
